Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(743)

Unified Diff: content/browser/renderer_host/render_message_filter.cc

Issue 2835403004: Revert "Use MojoCompositorFrameSink in RendererCompositorFrameSink"
Patch Set: Rebased Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/render_message_filter.cc
diff --git a/content/browser/renderer_host/render_message_filter.cc b/content/browser/renderer_host/render_message_filter.cc
index 90008a31a08fff87cab06800e887b7ad829494e2..fcc318701b404b6ccce79e7c22533479d51ad898 100644
--- a/content/browser/renderer_host/render_message_filter.cc
+++ b/content/browser/renderer_host/render_message_filter.cc
@@ -156,11 +156,18 @@ bool RenderMessageFilter::OnMessageReceived(const IPC::Message& message) {
bool handled = true;
IPC_BEGIN_MESSAGE_MAP(RenderMessageFilter, message)
#if defined(OS_MACOSX)
- // On Mac, ViewHostMsg_UpdateRect needs to be handled in a nested message
- // loop during resize.
+ // On Mac, the IPCs ViewHostMsg_SwapCompositorFrame, ViewHostMsg_UpdateRect,
+ // and GpuCommandBufferMsg_SwapBuffersCompleted need to be handled in a
+ // nested message loop during resize.
+ IPC_MESSAGE_HANDLER_GENERIC(
+ ViewHostMsg_SwapCompositorFrame,
+ ResizeHelperPostMsgToUIThread(render_process_id_, message))
IPC_MESSAGE_HANDLER_GENERIC(
ViewHostMsg_UpdateRect,
ResizeHelperPostMsgToUIThread(render_process_id_, message))
+ IPC_MESSAGE_HANDLER_GENERIC(
+ ViewHostMsg_SetNeedsBeginFrames,
+ ResizeHelperPostMsgToUIThread(render_process_id_, message))
#endif
IPC_MESSAGE_HANDLER_DELAY_REPLY(ChildProcessHostMsg_HasGpuProcess,
OnHasGpuProcess)
« no previous file with comments | « content/browser/renderer_host/frame_sink_provider_impl.cc ('k') | content/browser/renderer_host/render_process_host_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698